@@ -38,16 +38,21 @@ def get_user_function(source, source_module, target):
     """Returns user function, raises exception for invalid function."""
     # Extract the target function from the source file
     if not hasattr(source_module, target):
+        non_target_functions = ", ".join(
+            "'{attr}'".format(attr=attr)
+            for attr in dir(source_module)
+            if isinstance(getattr(source_module, attr), types.FunctionType)
+        )
         raise MissingTargetException(
-            "File {source} is expected to contain a function named {target}".format(
-                source=source, target=target
+            "File {source} is expected to contain a function named '{target}'. Found: {non_target_functions} instead".format(
+                source=source, target=target, non_target_functions=non_target_functions
             )
         )
     function = getattr(source_module, target)
     # Check that it is a function
     if not isinstance(function, types.FunctionType):
         raise InvalidTargetTypeException(
-            "The function defined in file {source} as {target} needs to be of "
+            "The function defined in file {source} as '{target}' needs to be of "
             "type function. Got: invalid type {target_type}".format(
                 source=source, target=target, target_type=type(function)
             )
@@ -62,7 +67,9 @@ def load_function_module(source):
     directory, filename = os.path.split(realpath)
     name, extension = os.path.splitext(filename)
     # 2. Create a new module
-    spec = importlib.util.spec_from_file_location(name, realpath)
+    spec = importlib.util.spec_from_file_location(
+        name, realpath, submodule_search_locations=[directory]
+    )
     source_module = importlib.util.module_from_spec(spec)
     # 3. Add the directory of the source to sys.path to allow the function to
     # load modules relative to its location
